nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Ist

Struct Ist 

#[repr(transparent)]
pub struct Ist(pub u32);
Pin interrupt status register

Tuple Fields

0: u32

Implementations

Source

impl Ist

pub const fn pstat(&self) -> u8

Pin interrupt status. Bit n returns the status, clears the edge interrupt, or inverts the active level of the pin selected in PINTSELn. Read 0: interrupt is not being requested for this interrupt pin. Write 0: no operation. Read 1: interrupt is being requested for this interrupt pin. Write 1 (edge-sensitive): clear rising- and falling-edge detection for this pin. Write 1 (level-sensitive): switch the active level for this pin (in the IENF register).

pub const fn set_pstat(&mut self, val: u8)

Pin interrupt status. Bit n returns the status, clears the edge interrupt, or inverts the active level of the pin selected in PINTSELn. Read 0: interrupt is not being requested for this interrupt pin. Write 0: no operation. Read 1: interrupt is being requested for this interrupt pin. Write 1 (edge-sensitive): clear rising- and falling-edge detection for this pin. Write 1 (level-sensitive): switch the active level for this pin (in the IENF register).