nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Pmcfg

Struct Pmcfg 

#[repr(transparent)]
pub struct Pmcfg(pub u32);
Pattern match interrupt bit slice configuration register

Tuple Fields

0: u32

Implementations

Source

impl Pmcfg

pub const fn prod_endpts0(&self) -> ProdEndpts0

Determines whether slice 0 is an endpoint.

pub const fn set_prod_endpts0(&mut self, val: ProdEndpts0)

Determines whether slice 0 is an endpoint.

pub const fn prod_endpts1(&self) -> ProdEndpts1

Determines whether slice 1 is an endpoint.

pub const fn set_prod_endpts1(&mut self, val: ProdEndpts1)

Determines whether slice 1 is an endpoint.

pub const fn prod_endpts2(&self) -> ProdEndpts2

Determines whether slice 2 is an endpoint.

pub const fn set_prod_endpts2(&mut self, val: ProdEndpts2)

Determines whether slice 2 is an endpoint.

pub const fn prod_endpts3(&self) -> ProdEndpts3

Determines whether slice 3 is an endpoint.

pub const fn set_prod_endpts3(&mut self, val: ProdEndpts3)

Determines whether slice 3 is an endpoint.

pub const fn prod_endpts4(&self) -> ProdEndpts4

Determines whether slice 4 is an endpoint.

pub const fn set_prod_endpts4(&mut self, val: ProdEndpts4)

Determines whether slice 4 is an endpoint.

pub const fn prod_endpts5(&self) -> ProdEndpts5

Determines whether slice 5 is an endpoint.

pub const fn set_prod_endpts5(&mut self, val: ProdEndpts5)

Determines whether slice 5 is an endpoint.

pub const fn prod_endpts6(&self) -> ProdEndpts6

Determines whether slice 6 is an endpoint.

pub const fn set_prod_endpts6(&mut self, val: ProdEndpts6)

Determines whether slice 6 is an endpoint.

pub const fn cfg0(&self) -> Cfg0

Specifies the match contribution condition for bit slice 0.

pub const fn set_cfg0(&mut self, val: Cfg0)

Specifies the match contribution condition for bit slice 0.

pub const fn cfg1(&self) -> Cfg1

Specifies the match contribution condition for bit slice 1.

pub const fn set_cfg1(&mut self, val: Cfg1)

Specifies the match contribution condition for bit slice 1.

pub const fn cfg2(&self) -> Cfg2

Specifies the match contribution condition for bit slice 2.

pub const fn set_cfg2(&mut self, val: Cfg2)

Specifies the match contribution condition for bit slice 2.

pub const fn cfg3(&self) -> Cfg3

Specifies the match contribution condition for bit slice 3.

pub const fn set_cfg3(&mut self, val: Cfg3)

Specifies the match contribution condition for bit slice 3.

pub const fn cfg4(&self) -> Cfg4

Specifies the match contribution condition for bit slice 4.

pub const fn set_cfg4(&mut self, val: Cfg4)

Specifies the match contribution condition for bit slice 4.

pub const fn cfg5(&self) -> Cfg5

Specifies the match contribution condition for bit slice 5.

pub const fn set_cfg5(&mut self, val: Cfg5)

Specifies the match contribution condition for bit slice 5.

pub const fn cfg6(&self) -> Cfg6

Specifies the match contribution condition for bit slice 6.

pub const fn set_cfg6(&mut self, val: Cfg6)

Specifies the match contribution condition for bit slice 6.

pub const fn cfg7(&self) -> Cfg7

Specifies the match contribution condition for bit slice 7.

pub const fn set_cfg7(&mut self, val: Cfg7)

Specifies the match contribution condition for bit slice 7.