nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Pmctrl

Struct Pmctrl 

#[repr(transparent)]
pub struct Pmctrl(pub u32);
Pattern match interrupt control register

Tuple Fields

0: u32

Implementations

Source

impl Pmctrl

pub const fn sel_pmatch(&self) -> SelPmatch

Specifies whether the 8 pin interrupts are controlled by the pin interrupt function or by the pattern match function.

pub const fn set_sel_pmatch(&mut self, val: SelPmatch)

Specifies whether the 8 pin interrupts are controlled by the pin interrupt function or by the pattern match function.

pub const fn ena_rxev(&self) -> bool

Enables the RXEV output to the CPU and/or to a GPIO output when the specified boolean expression evaluates to true.

pub const fn set_ena_rxev(&mut self, val: bool)

Enables the RXEV output to the CPU and/or to a GPIO output when the specified boolean expression evaluates to true.

pub const fn pmat(&self) -> u8

This field displays the current state of pattern matches. A 1 in any bit of this field indicates that the corresponding product term is matched by the current state of the appropriate inputs.

pub const fn set_pmat(&mut self, val: u8)

This field displays the current state of pattern matches. A 1 in any bit of this field indicates that the corresponding product term is matched by the current state of the appropriate inputs.