nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Rise

Struct Rise 

#[repr(transparent)]
pub struct Rise(pub u32);
Pin interrupt rising edge register

Tuple Fields

0: u32

Implementations

Source

impl Rise

pub const fn rdet(&self) -> u8

Rising edge detect. Bit n detects the rising edge of the pin selected in PINTSELn. Read 0: No rising edge has been detected on this pin since Reset or the last time a one was written to this bit. Write 0: no operation. Read 1: a rising edge has been detected since Reset or the last time a one was written to this bit. Write 1: clear rising edge detection for this pin.

pub const fn set_rdet(&mut self, val: u8)

Rising edge detect. Bit n detects the rising edge of the pin selected in PINTSELn. Read 0: No rising edge has been detected on this pin since Reset or the last time a one was written to this bit. Write 0: no operation. Read 1: a rising edge has been detected since Reset or the last time a one was written to this bit. Write 1: clear rising edge detection for this pin.