nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Sienf

Struct Sienf 

#[repr(transparent)]
pub struct Sienf(pub u32);
Pin interrupt active level or falling edge interrupt set register

Tuple Fields

0: u32

Implementations

Source

impl Sienf

pub const fn setenaf(&self) -> u8

Ones written to this address set bits in the IENF, thus enabling interrupts. Bit n sets bit n in the IENF register. 0 = No operation. 1 = Select HIGH-active interrupt or enable falling edge interrupt.

pub const fn set_setenaf(&mut self, val: u8)

Ones written to this address set bits in the IENF, thus enabling interrupts. Bit n sets bit n in the IENF register. 0 = No operation. 1 = Select HIGH-active interrupt or enable falling edge interrupt.